@@ -17,7 +17,7 @@ for path in sorted(Path("src").rglob("*.py")):
         parts = parts[:-1]
         doc_path = doc_path.with_name("index.md")
         full_doc_path = full_doc_path.with_name("index.md")
-    elif parts[-1] == "__main__":
+    elif parts[-1].startswith("_"):
         continue
 
     nav[parts] = doc_path.as_posix()
