@@ -2,14 +2,21 @@
 
 from __future__ import annotations
 
-import subprocess  # noqa: S404
+import subprocess
+from typing import Any
 
 from markdown_exec.formatters.base import ExecutionError, base_format
 from markdown_exec.rendering import code_block
 
 
-def _run_bash(code: str, *, returncode: int = 0, **extra: str) -> str:
-    process = subprocess.run(  # noqa: S603,S607
+def _run_bash(
+    code: str,
+    returncode: int | None = None,
+    session: str | None = None,  # noqa: ARG001
+    id: str | None = None,  # noqa: A002,ARG001
+    **extra: str,
+) -> str:
+    process = subprocess.run(
         ["bash", "-c", code],
         stdout=subprocess.PIPE,
         stderr=subprocess.STDOUT,
@@ -20,5 +27,5 @@ def _run_bash(code: str, *, returncode: int = 0, **extra: str) -> str:
     return process.stdout
 
 
-def _format_bash(**kwargs) -> str:
+def _format_bash(**kwargs: Any) -> str:
     return base_format(language="bash", run=_run_bash, **kwargs)
